@@ -99,10 +99,14 @@ shinyUI(fluidPage(
           textInput("title1",h6(gettext("Title of the graph: ")), title1)
         ),
         fluidRow(
-          column(5,selectInput("nb1", label = h6(gettext("x axis")), 
-                               choices = list("1" = 1, "2" = 2, "3" = 3,"4"= 4,"5" =5), selected = 1,width='80%')),
-          column(5,selectInput("nb2", label =h6(gettext("y axis")), 
-                               choices = list("1" = 1, "2" = 2,"3" = 3,"4"= 4,"5" =5), selected = 2,width='80%')))
+          # column(5,selectInput("nb1", label = h6(gettext("x axis")), 
+                               # choices = list("1" = 1, "2" = 2, "3" = 3,"4"= 4,"5" =5), selected = 1,width='80%')),
+        column(5,textInput("nb1", label = h6(gettext("x axis")), 1,width='50%')),
+
+		
+          # column(5,selectInput("nb2", label =h6(gettext("y axis")), 
+                               # choices = list("1" = 1, "2" = 2,"3" = 3,"4"= 4,"5" =5), selected = 2,width='80%')))
+        column(5,textInput("nb2", label = h6(gettext("y axis")), 2,width='50%')))
         )),
         wellPanel(
           h5(gettext("Save graphs as"),align="center"),
