@@ -70,7 +70,7 @@ shinyServer(
       # }
 	  suple=which(nom%in%input$indsup)
     }
-    list(res.PCA=(PCA(data.selec,quali.sup=choixquali,quanti.sup=choixquanti,scale.unit=input$nor,graph=FALSE,ncp=5,ind.sup=suple,row.w=poids1,col.w=poids2)),DATA=(data.selec),choixquant=(choixquanti),choixqual=(choixquali),choixsuple=(suple))
+    list(res.PCA=(PCA(data.selec,quali.sup=choixquali,quanti.sup=choixquanti,scale.unit=input$nor,graph=FALSE,ncp=max(5,as.numeric(input$nb1),as.numeric(input$nb2)),ind.sup=suple,row.w=poids1,col.w=poids2)),DATA=(data.selec),choixquant=(choixquanti),choixqual=(choixquali),choixsuple=(suple))
     })
     
     Plot1 <- reactive({
@@ -241,9 +241,9 @@ shinyServer(
       sup=values()$choixsuple
       if(!is.null(sup)){
         if(!is.null(supind)){
-        return(shinyjs::colourInput("colorsup", h6(gettext("Choose colour for supplementary individuals")), supind))
+        return(colourpicker::colourInput("colorsup", h6(gettext("Choose colour for supplementary individuals")), supind))
         }else{
-          return(shinyjs::colourInput("colorsup", h6(gettext("Choose colour for supplementary individuals")), "blue")) 
+          return(colourpicker::colourInput("colorsup", h6(gettext("Choose colour for supplementary individuals")), "blue")) 
         }
       }
     })
@@ -252,9 +252,9 @@ shinyServer(
       sup=values()$choixqual
       if(!is.null(sup)){
         if(!is.null(categ)){
-        return(shinyjs::colourInput("colorquali", h6(gettext("Choose colour for the categories")), categ))
+        return(colourpicker::colourInput("colorquali", h6(gettext("Choose colour for the categories")), categ))
         }else{
-          return(shinyjs::colourInput("colorquali", h6(gettext("Choose colour for the categories")), "magenta"))
+          return(colourpicker::colourInput("colorquali", h6(gettext("Choose colour for the categories")), "magenta"))
         }
       }
     })
@@ -497,13 +497,13 @@ shinyServer(
         pcol=paste(",col.w=c(",paste(poids2,collapse=","),")",sep="")
       }
       if(!is.null(poids1)&&!is.null(poids2)){
-        Call1=as.name(paste("res.PCA<-PCA(",vec,",quali.sup=",vecqual,",","quanti.sup=",vecquant,",ind.sup=",indsupl,prow,pcol,",scale.unit=",input$nor,",graph=FALSE,ncp=5)",sep="")) 
+        Call1=as.name(paste("res.PCA<-PCA(",vec,",quali.sup=",vecqual,",","quanti.sup=",vecquant,",ind.sup=",indsupl,prow,pcol,",scale.unit=",input$nor,",graph=FALSE,ncp=",max(5,as.numeric(input$nb1),as.numeric(input$nb2)),")",sep="")) 
       }else if (!is.null(poids1)&&is.null(poids2)){
-        Call1=as.name(paste("res.PCA<-PCA(",vec,",quali.sup=",vecqual,",","quanti.sup=",vecquant,",ind.sup=",indsupl,prow,",scale.unit=",input$nor,",graph=FALSE,ncp=5)",sep="")) 
+        Call1=as.name(paste("res.PCA<-PCA(",vec,",quali.sup=",vecqual,",","quanti.sup=",vecquant,",ind.sup=",indsupl,prow,",scale.unit=",input$nor,",graph=FALSE,ncp=",max(5,as.numeric(input$nb1),as.numeric(input$nb2)),")",sep="")) 
       }else if (is.null(poids1)&&!is.null(poids1)){
-        Call1=as.name(paste("res.PCA<-PCA(",vec,",quali.sup=",vecqual,",","quanti.sup=",vecquant,",ind.sup=",indsupl,pcol,",scale.unit=",input$nor,",graph=FALSE,ncp=5)",sep="")) 
+        Call1=as.name(paste("res.PCA<-PCA(",vec,",quali.sup=",vecqual,",","quanti.sup=",vecquant,",ind.sup=",indsupl,pcol,",scale.unit=",input$nor,",graph=FALSE,ncp=",max(5,as.numeric(input$nb1),as.numeric(input$nb2)),")",sep="")) 
       }else{
-      Call1=as.name(paste("res.PCA<-PCA(",vec,",quali.sup=",vecqual,",","quanti.sup=",vecquant,",ind.sup=",indsupl,",scale.unit=",input$nor,",graph=FALSE,ncp=5)",sep=""))
+      Call1=as.name(paste("res.PCA<-PCA(",vec,",quali.sup=",vecqual,",","quanti.sup=",vecquant,",ind.sup=",indsupl,",scale.unit=",input$nor,",graph=FALSE,ncp=",max(5,as.numeric(input$nb1),as.numeric(input$nb2)),")",sep=""))
       }
       return(Call1)
     }
@@ -649,8 +649,9 @@ shinyServer(
         need(length(getactive())>1 || input$selecactive==gettext("All"),gettext("Please select at least one supplementary variable"))
       )
       if(input$selecactive==gettext("All") || length(getactive())>5){
-        return(selectInput("nb1", label = h6(gettext("x axis")), 
-                    choices = list("1" = 1, "2" = 2, "3" = 3,"4"= 4,"5" =5), selected = axe1,width='80%'))
+        # return(selectInput("nb1", label = h6(gettext("x axis")), 
+                            # choices = list("1" = 1, "2" = 2, "3" = 3,"4"= 4,"5" =5,"6"=6,"7"=7), selected = axe1,width='80%'))
+        return(textInput("nb1", label = h6(gettext("x axis")), axe1,width='50%'))
       }
       else{
         baba=c(1:length(getactive()))
@@ -663,8 +664,9 @@ shinyServer(
         need(length(getactive())>1 || input$selecactive==gettext("All"),gettext("Please select at least one supplementary variable"))
       )
       if(input$selecactive==gettext("All") || length(getactive())>5){
-        return(selectInput("nb2", label = h6(gettext("y axis")), 
-                           choices = list("1" = 1, "2" = 2, "3" = 3,"4"= 4,"5" =5), selected = axe2,width='80%'))
+        # return(selectInput("nb2", label = h6(gettext("y axis")), 
+                           # choices = list("1" = 1, "2" = 2, "3" = 3,"4"= 4,"5" =5,"6"=6,"7"=7), selected = axe2,width='80%'))
+        return(textInput("nb2", label = h6(gettext("y axis")), axe2,width='50%'))
       }
       else{
         baba=c(1:length(getactive()))
@@ -674,7 +676,7 @@ shinyServer(
     
     output$sorties=renderTable({
         return(as.data.frame(values()$res.PCA$eig))
-    })
+    },rownames=TRUE)
     
     output$sorties12=renderTable({
         validate(
@@ -684,7 +686,7 @@ shinyServer(
           need(length(getactive())>1 || input$selecactive==gettext("All"),gettext("Please select at least one supplementary variable"))
         )
         return(as.data.frame(values()$res.PCA$quali.sup$coord))
-    })
+    },rownames=TRUE)
     
     output$sorties13=renderTable({
       validate(
@@ -694,21 +696,21 @@ shinyServer(
         need((length(input$supquali)>0 || input$supquali==TRUE), gettext("No categorical variables selected"))
       )
       return(as.data.frame(values()$res.PCA$quali.sup$v.test))
-    })
+    },rownames=TRUE)
     
     output$sorties2=renderTable({
       validate(
         need(length(getactive())>1 || input$selecactive==gettext("All"),gettext("Please select at least one supplementary variable"))
       )
       return(as.data.frame(values()$res.PCA$var$coord))
-    })
+    },rownames=TRUE)
     
     output$sorties22=renderTable({
       validate(
         need(length(getactive())>1 || input$selecactive==gettext("All"),gettext("Please select at least one supplementary variable"))
       )
       return(as.data.frame(values()$res.PCA$ind$coord))
-    })
+    },rownames=TRUE)
     
     output$sorties23=renderTable({
       validate(
@@ -718,7 +720,7 @@ shinyServer(
         need(length(input$getactive())>1 || input$selecactive==gettext("All"),gettext("Please select at least one supplementary variable"))
       )
       return(as.data.frame(values()$res.PCA$quanti.sup$coord))
-    })
+    },rownames=TRUE)
     
     output$sorties32=renderTable({
       validate(
@@ -728,7 +730,7 @@ shinyServer(
         need(length(getactive())>1 || input$selecactive==gettext("All"),gettext("Please select at least one supplementary variable"))
       )
       return(as.data.frame(values()$res.PCA$quanti.sup$cor))
-    })
+    },rownames=TRUE)
     
     output$sorties36=renderTable({
       validate(
@@ -738,7 +740,7 @@ shinyServer(
         need(length(getactive())>1 || input$selecactive==gettext("All"),gettext("Please select at least one supplementary variables"))
       )
       return(as.data.frame(values()$res.PCA$ind.sup$coord))
-    })
+    },rownames=TRUE)
     
     output$sorties37=renderTable({
       validate(
@@ -748,7 +750,7 @@ shinyServer(
         need(length(getactive())>1 || input$selecactive==gettext("All"),gettext("Please select at least one supplementary variable"))
       )
       return(as.data.frame(values()$res.PCA$ind.sup$cos2))
-    })
+    },rownames=TRUE)
     
     
     output$sorties3=renderTable({
@@ -756,28 +758,28 @@ shinyServer(
         need(length(getactive())>1 || input$selecactive==gettext("All"),gettext("Please select at least one supplementary variable"))
       )
       return(as.data.frame(values()$res.PCA$var$contrib))
-    })
+    },rownames=TRUE)
     
     output$sorties33=renderTable({
       validate(
         need(length(getactive())>1 || input$selecactive==gettext("All"),gettext("Please select at least one supplementary variable"))
       )
       return(as.data.frame(values()$res.PCA$ind$contrib))
-    })
+    },rownames=TRUE)
     
     output$sorties4=renderTable({
       validate(
         need(length(getactive())>1 || input$selecactive==gettext("All"),gettext("Please select at least one supplementary variable"))
       )
       return(as.data.frame(values()$res.PCA$var$cos2))
-    })
+    },rownames=TRUE)
     
     output$sorties44=renderTable({
       validate(
         need(length(getactive())>1 || input$selecactive==gettext("All"),gettext("Please select at least one supplementary variable"))
       )
       return(as.data.frame(values()$res.PCA$ind$cos2))
-    })
+    },rownames=TRUE)
   
   output$sortieDimdesc3=renderTable({
     validate(
@@ -785,7 +787,7 @@ shinyServer(
     )
     validate(need(length(dimdesc(values()$res.PCA))>0,gettext("No quantitative variable describes axis 1")))
     return(as.data.frame(dimdesc(values()$res.PCA)[[1]]$quanti))
-  })
+  },rownames=TRUE)
   
   output$sortieDimdesc4=renderTable({
     validate(
@@ -793,7 +795,7 @@ shinyServer(
     )
     validate(need(length(dimdesc(values()$res.PCA))>0,gettext("No categorical variable describes axis 1")))
     return(as.data.frame(dimdesc(values()$res.PCA)[[1]]$quali))
-  })
+  },rownames=TRUE)
   
   #DIM2
   
@@ -803,7 +805,7 @@ shinyServer(
     )
     validate(need(length(dimdesc(values()$res.PCA))>1,gettext("No quantitative variable describes axis 2")))
     return(as.data.frame(dimdesc(values()$res.PCA)[[2]]$quanti))
-  })
+  },rownames=TRUE)
   
   output$sortieDimdesc44=renderTable({
     validate(
@@ -811,7 +813,7 @@ shinyServer(
     )
     validate(need(length(dimdesc(values()$res.PCA))>1,gettext("No categorical variable describes axis 2")))
     return(as.data.frame(dimdesc(values()$res.PCA)[[2]]$quali))
-  })
+  },rownames=TRUE)
   
   #DIM3
   
@@ -821,7 +823,7 @@ shinyServer(
     )
     validate(need(length(dimdesc(values()$res.PCA))>2,gettext("No quantitative variable describes axis 3")))
     return(as.data.frame(dimdesc(values()$res.PCA)[[3]]$quanti))
-  })
+  },rownames=TRUE)
   
   output$sortieDimdesc444=renderTable({
     validate(
@@ -829,7 +831,7 @@ shinyServer(
     )
     validate(need(length(dimdesc(values()$res.PCA))>2,"No categorical variable describes axis 3"))
     return(as.data.frame(dimdesc(values()$res.PCA)[[3]]$quali))
-  })
+  },rownames=TRUE)
     
     
     output$map3=renderPlot({
@@ -913,9 +915,9 @@ shinyServer(
     test=values()$choixquant
     if(!is.null(test)){
       if(!is.null(colorsupvar)){
-        return(shinyjs::colourInput("colorsupvar", h6(gettext("Choose colour for supplementary variables")), colorsupvar))
+        return(colourpicker::colourInput("colorsupvar", h6(gettext("Choose colour for supplementary variables")), colorsupvar))
       }else{
-      return(shinyjs::colourInput("colorsupvar", h6(gettext("Choose colour for supplementary variables")), "blue"))
+      return(colourpicker::colourInput("colorsupvar", h6(gettext("Choose colour for supplementary variables")), "blue"))
       }
     }
   })
